# better_pynamite

[![forthebadge](https://forthebadge.com/images/badges/powered-by-black-magic.svg)](https://forthebadge.com)

Added `better_` because the name `pynamite` was already taken.

## Setup and installation

[TODO: setup pip]

1. Simply install with

```
pip install better_pynamite
```

2. Import in victim script

```
import better_pynamite
```

3. Let the chaos unfold

## Todo

[for when I/someone else opens this repo again after ages]

[ ] Add a way to configure the probability fo crashing during import. Right now it has been set to `0.5` which is VERY high, especially if you're trying to be sneaky

## A word of caution

This package is a product of boredom + my chaotic mind and is not intended to cause harm to anyone in any way. Please use it at your own risk or for any pranks you might like. I DO NOT take any responsibility for any consequences arising out of your actions using this package.

On the other hand, if you have any witty ideas, please feel free to open an issue and we can have a chat to see if it's a good idea to add it here!
